#!/usr/bin/python3
# vim:se tw=0 sts=4 ts=4 et ai:
"""
Script to test imediff module

Use as:

 $ python3 _imediff ...

"""
import imediff

imediff.main()
